@@ -123,9 +123,8 @@ shm_create_buffer(struct wl_client *client, struct wl_resource *resource,
 
 
 	switch (format) {
-	case WL_SHM_FORMAT_ARGB32:
-	case WL_SHM_FORMAT_PREMULTIPLIED_ARGB32:
-	case WL_SHM_FORMAT_XRGB32:
+	case WL_SHM_FORMAT_ARGB8888:
+	case WL_SHM_FORMAT_XRGB8888:
 		break;
 	default:
 		wl_resource_post_error(resource,
@@ -179,10 +178,10 @@ bind_shm(struct wl_client *client,
 	resource = wl_client_add_object(client, &wl_shm_interface,
 					&shm_interface, id, data);
 
-	wl_resource_post_event(resource, WL_SHM_FORMAT, WL_SHM_FORMAT_ARGB32);
 	wl_resource_post_event(resource, WL_SHM_FORMAT,
-			       WL_SHM_FORMAT_PREMULTIPLIED_ARGB32);
-	wl_resource_post_event(resource, WL_SHM_FORMAT, WL_SHM_FORMAT_XRGB32);
+			       WL_SHM_FORMAT_ARGB8888);
+	wl_resource_post_event(resource, WL_SHM_FORMAT,
+			       WL_SHM_FORMAT_XRGB8888);
 }
 
 WL_EXPORT struct wl_shm *
